pub struct Route {
pub coordinates: Vec<(f64, f64)>,
pub cumulative_times_s: Vec<f64>,
pub distance_m: f64,
pub duration_s: f64,
}Fields
coordinates: Vec<(f64, f64)>Ordered list of (lat, lon) coordinates along the route
cumulative_times_s: Vec<f64>Cumulative travel time in seconds at each coordinate (parallel to coordinates)
distance_m: f64Total route distance in meters
duration_s: f64Total travel time in seconds for the given network type